# -*- coding: utf-8; mode: cython -*-

cdef extern from "finitediff_c.h":
     cdef int calculate_weights(double *, int, double *, int, int, double)
     cdef int apply_fd(double *, int, int, int, int, double *, double *, int, double)



from .rebalance import rebalanced_grid, pre_pruning_mask, combine_grids, grid_pruning_mask
from .refine import refine_grid
from .make import adapted_grid
from .util import locate_discontinuity, pool_discontinuity_approx, grid_error
from .plotting import plot_convergence
